Date: 07 23, 2001 10:02:57 AM

# Running Analyzer on Multiple Files

You can run an analyzer on multiple files contained in a tree of folders.

To run an analyzer on a tree of folders:

1. Select the top level folder in the Text Tab.

2. Click on the Run button in the Workspace Toolbar.

Note: Log files generated for the text are placed under (indented and to the right of) the text file.

Tips: You can also select Run from the Analyzer Menu.

##